@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# copyright 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2003-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
 #
 # This file is part of logilab-common.
@@ -132,9 +132,20 @@ def get_threshold(debug=False, logthreshold=None):
                                                           logthreshold))
     return logthreshold
 
-def get_formatter(logformat=LOG_FORMAT, logdateformat=LOG_DATE_FORMAT):
+def _colorable_terminal():
     isatty = hasattr(sys.__stdout__, 'isatty') and sys.__stdout__.isatty()
-    if isatty and sys.platform != 'win32':
+    if not isatty:
+        return False
+    if os.name == 'nt':
+        try:
+            from colorama import init as init_win32_colors
+        except ImportError:
+            return False
+        init_win32_colors()
+    return True
+
+def get_formatter(logformat=LOG_FORMAT, logdateformat=LOG_DATE_FORMAT):
+    if _colorable_terminal():
         fmt = ColorFormatter(logformat, logdateformat)
         def col_fact(record):
             if 'XXX' in record.message:
@@ -159,7 +170,10 @@ def init_log(debug=False, syslog=False, logthreshold=None, logfile=None,
     logthreshold = get_threshold(debug, logthreshold)
     logger.setLevel(logthreshold)
     if fmt is None:
-        fmt = get_formatter(logformat=LOG_FORMAT, logdateformat=LOG_DATE_FORMAT)
+        if debug:
+            fmt = get_formatter(logformat=logformat, logdateformat=logdateformat)
+        else:
+            fmt = logging.Formatter(logformat, logdateformat)
     handler.setFormatter(fmt)
     return handler
 
